erc-discuss
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: [Erc-discuss] Re: new erc-nickserv-identified-hook


From: Giorgos Keramidas
Subject: Re: [Erc-discuss] Re: new erc-nickserv-identified-hook
Date: Sun, 9 Dec 2007 06:38:20 +0200

On 2007-12-09 05:58, Giorgos Keramidas <address@hidden> wrote:
> On 2007-12-08 21:21, Michael Olson <address@hidden> wrote:
> > Giorgos Keramidas <address@hidden> writes:
> > > I'm using ERC that is bundled with CVS snapshots of Emacs, to chat on
> > > the GRnet IRC network (*.irc.gr), so I can update the regexp for that
> > > network too.
> >
> > I'm in the process of syncing it to Emacs.  It would be good to have
> > that regexp.
>
> I don't have the latest version of the ERC source code around, but
> here's a typical exchange of messages when identifying (raw telnet
> session)...
>
> Lines marked with `<-- ' are received from the server.
>
> Lines marked with `--> ' are the ones I typed.
>
> <-- :address@hidden NOTICE keramida :This nickname is registered and 
> protected.  If it is your
> <-- :address@hidden NOTICE keramida :nick, type /IDENTIFY password.  
> Otherwise,
> <-- :address@hidden NOTICE keramida :please choose a different nick.
> <-- :address@hidden NOTICE keramida :If you do not change within one minute, 
> I will change your nick.
>
> --> IDENTIFY ********
>
> <-- :address@hidden NOTICE keramida :Password accepted - you are now 
> recognized.
> <-- :address@hidden NOTICE keramida :Cookie: You can find some people from 
> the same town by typing: /who +h *mask*  E.g.: For people from Athens: /who 
> +h *ath*

Ok, if I got the patch right, the following should add the necessary
bits for auto-identifying on GRnet.

This is the first time I'm emailing patches extracted from Git, so if I
did something silly while preparing the patch let me know :)

%%%
commit 5ac224285768b7193809d86dbcb26798bf584124
Author: Giorgos Keramidas <address@hidden>
Date:   Sun Dec 9 06:32:52 2007 +0200

    Add identification hooks for GRnet, the Greek IRC network.

diff --git a/ChangeLog b/ChangeLog
index e789fd2..349b1b9 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2007-12-09  Giorgos Keramidas  <address@hidden>
+
+       * erc-services.el: Add identification hooks for GRnet, the Greek
+       IRC network <http://www.irc.gr>.
+
 2007-12-07  Edward O'Connor  <address@hidden>
 
        * erc-services.el: Provide a hook that runs when nickserv confirms
diff --git a/erc-services.el b/erc-services.el
index 6cf21e8..224b464 100644
--- a/erc-services.el
+++ b/erc-services.el
@@ -29,9 +29,10 @@
 ;; are made to test if NickServ is the real NickServ for a given network or
 ;; server.
 
 ;; As a default, ERC has the data for the official nickname services on the
 ;; networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, and Slashnet.
 ;; You can add more by using M-x customize-variable RET erc-nickserv-alist.
 
 ;; Usage:
 ;;
@@ -182,6 +183,7 @@ Example of use:
                        (const DALnet)
                        (const freenode)
                        (const GalaxyNet)
+                       (const GRnet)
                        (const iip)
                        (const OFTC)
                        (const QuakeNet)
@@ -234,6 +236,12 @@ Example of use:
      "Please\\s-change\\s-nicks\\s-or\\s-authenticate."
      "address@hidden"
      "AUTH" t nil nil)
+    (GRnet
+     "address@hidden"
+     "This\\snickname\\sis\\sregistered\\sand\\sprotected."
+     "NickServ"
+     "IDENTIFY" nil nil
+     "Password\\saccepted\\s-\\syou\\sare\\snow\\srecognized.")
     (iip
      "address@hidden"
      "type\\s-/squery\\s-Trent\\s-identify\\s-<password>"
@@ -29,9 +29,10 @@
 ;; server.
 
-;; As a default, ERC has the data for the official nickname services on the
-;; networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, and Slashnet.
-;; You can add more by using M-x customize-variable RET erc-nickserv-alist.
+;; As a default, ERC has the data for the official nickname services on
+;; the networks Austnet, BrasNET, Dalnet, freenode, GalaxyNet, GRnet,
+;; and Slashnet.  You can add more by using M-x customize-variable RET
+;; erc-nickserv-alist.
 
 ;; Usage:
%%%




reply via email to

[Prev in Thread] Current Thread [Next in Thread]